@@ -7,9 +7,7 @@
 #' @param normalTumorArray Only in the case of normal-tumor study. A csv file or a data.frame containing the mapping between normal and tumor files.
 #' The first column contains the name of normal files and the second the names of associated tumor files.
 #' @param chromosome  A vector with the chromosomes to be segmented. 
-#' @param method method of segmentation, either "PELT" or "cghseg".
-#' @param Rho For method="PELT", vector containing all the penalization values to test for the segmentation. If no values are provided, default values will be used.
-#' @param Kmax For method="cghseg", maximal number of segments.
+#' @param Rho Vector containing all the penalization values to test for the segmentation. If no values are provided, default values will be used.
 #' @param listOfFiles A vector containing the names of the files in dataSetName folder for which the allele B profile is segmented (default is all the files).
 #' @param savePlot if TRUE, graphics of the segmented allele B profile will be saved in the figures/dataSetName/segmentation/fracB folder. (default=TRUE).
 #' @param verbose if TRUE print some informations
@@ -28,38 +26,36 @@
 #' 
 #' @author Quentin Grimonprez
 #' 
-segFracBSignal=function(dataSetName,normalTumorArray,chromosome=1:22,method=c("cghseg","PELT"),Rho=NULL,Kmax=10,listOfFiles=NULL,savePlot=TRUE,verbose=TRUE)
+segFracBSignal=function(dataSetName,normalTumorArray,chromosome=1:22,Rho=NULL,listOfFiles=NULL,savePlot=TRUE,verbose=TRUE)
 {
-  method <- match.arg(method)
   
   allpkg=TRUE
-  if(!suppressPackageStartupMessages(require("aroma.affymetrix", quietly=TRUE) ) )
+  if(!suppressPackageStartupMessages(requireNamespace("aroma.affymetrix", quietly=TRUE) ) )
   {
-    cat("Package not found: aroma.affymetrix. For download it:\n")
-    cat("source(\"http://www.braju.com/R/hbLite.R\")\n")
-    cat(" hbLite(\"sfit\")\n")
-    cat("source(\"http://bioconductor.org/biocLite.R\")\n")
-    cat("biocLite(\"affxparser\")\n")
-    cat("biocLite(\"DNAcopy\")\n")
-    cat("biocLite(\"aroma.light\")\n")
-    #     cat("source(\"http://aroma-project.org/hbLite.R\")\n")
-    cat("install.packages(\"aroma.affymetrix\")\n")
+    message("Package not found: aroma.affymetrix. For download it:\n")
+    message("source(\"http://callr.org/install#HenrikBengtsson/sfit\")\n")
+    message("if (!requireNamespace(\"BiocManager\", quietly = TRUE))\n")
+    message("install.packages(\"BiocManager\")\n")
+    message("BiocManager::install(\"affxparser\")\n")
+    message("BiocManager::install(\"DNAcopy\")\n")
+    message("BiocManager::install(\"aroma.light\")\n")
+    message("install.packages(\"aroma.affymetrix\")\n")
     allpkg=FALSE
   }
 
-  if(!suppressPackageStartupMessages(require("aroma.cn", quietly=TRUE) ) )
+  if(!suppressPackageStartupMessages(requireNamespace("aroma.cn", quietly=TRUE) ) )
   {
-    cat("Package not found: aroma.cn. For download it:\n")
-    cat("install.packages(\"aroma.cn\")\n") 
+    message("Package not found: aroma.cn. For download it:\n")
+    message("install.packages(\"aroma.cn\")\n") 
     allpkg=FALSE
   }
   
   if(!allpkg)
     stop("You have to install some packages : Follow the printed informations.")
   
-  require(aroma.core)
-  require(R.devices)
-  require(R.filesets)
+  requireNamespace("aroma.core")
+  requireNamespace("R.devices")
+  requireNamespace("R.filesets")
   
   if(!("totalAndFracBData"%in%list.files()))
     stop("There is no \"totalAndFracBData\", check if you are in the good working directory or if you have run the signalPreProcess function before.")
@@ -208,15 +204,13 @@ segFracBSignal=function(dataSetName,normalTumorArray,chromosome=1:22,method=c("c
 
       
       #segmentation
-      cat(paste0("Segmentation of file ",name," chromosome ",chr,"..."))
+      message(paste0("Segmentation of file ",name," chromosome ",chr,"..."))
       
       if (is.null(fracB[,3]) || length(fracB[,3])<2){
-        cat("to few point to segment \n")
+        message("to few point to segment \n")
       } else {
-        seg=switch(method,
-          PELT=PELT(fracB[,3],Rho,position=fracB$position,plot=TRUE,verbose=verbose),
-          cghseg=cghseg(fracB[,3],Kmax,position=fracB$position,plot=TRUE,verbose=verbose))
-        cat("OK\n")
+        seg=PELT(fracB[,3],Rho,position=fracB$position,plot=TRUE,verbose=verbose)
+        message("OK\n")
         
         if(savePlot)
         {
